.. _documentation-statistics-label:

===================
Notes on statistics
===================

The following urls are helpful to understand the statistical treatment of the uncertainties on the content of each bin of a histogram:

- `Note about uncertainties when the histogram entries are weighted. <https://www.pp.rhul.ac.uk/~cowan/stat/notes/errors_with_weights.pdf>`_
- `Presentation about asymmetrical uncertainties. <https://www.nikhef.nl/~ivov/Statistics/PoissonError/2017_05_15_PoissonError_LHCb_IvovanVulpen.pdf>`_
